#!/bin/sh

#Copyright (C) since 2006 NTT DATA Corporation
#
#This program is free software; you can redistribute it and/or
#Modify it under the terms of the GNU General Public License
#as published by the Free Software Foundation, version 2.
#
#This program is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details

. /opt/hinemos/hinemos.cfg

# check for incorrect use
EXEC_USER=`/usr/bin/whoami`
if [ ${EXEC_USER} != "hinemos" ]; then
        echo "";
        echo "ERROR  Hinemos Maneger boot at incorrect user ";
        echo "";
        exit 1;
fi

if [ -f ${HINEMOS_LDAP_PID} ] ; then

        read LDAP_PID < ${HINEMOS_LDAP_PID}
        ps -p ${LDAP_PID} > /dev/null && TMP=1
        if [ "$TMP" ] ; then
                echo ""
                echo "======================================================"
                echo "ERROR another slapd may be runnning."
                echo "pid file (${HINEMOS_LDAP_PID}) is exist."
                echo "======================================================"
                exit 24
        else
                rm -f ${HINEMOS_LDAP_PID}
        fi
fi

echo "waiting for slapd to start..."
${LDAP}/libexec/slapd -h "ldap://0.0.0.0:24000/"
REVAL=$?
if [ $REVAL -ne 0 ]; then
        echo "ERROR  It may not start normally."
        exit 2
fi

echo "done"
echo "slapd started"
